/*
    Mutual Track Mat
        (C) あかつきみさき(みくちぃP)

    このスクリプトについて
        選択したレイヤーを相互のアルファトラックマット状態にし,トラックマットを設定したレイヤーをすべて表示します.
        レイヤーが3つ以上選択している場合,選択順からすくみの関係になります.

    使用方法
        ファイル→スクリプト→スクリプトファイルを実行.

    動作環境
        Adobe After Effects 2023以上

    バージョン情報
        2022/12/31 Ver 1.0.0 Release
*/

/// <reference path="D:\lib\aftereffects.d.ts\ae.d.ts"/>

(function () {
    if(parseFloat(app.version) < 23.0){
        alert("This script requires After Effects 2023(23.0) or greater.","Mutual Track Mat");
        return 0;
    }
    
    var actComp = app.project.activeItem;
    if (actComp == null || !(actComp instanceof CompItem)) {
        return 0;
    }

    var selLayers = actComp.selectedLayers;
    var avLayers = [];
    for (var i = 0; i < selLayers.length; i++) {
        if ((selLayers[i] instanceof AVLayer) || (selLayers[i] instanceof ShapeLayer)) {
            avLayers[avLayers.length] = selLayers[i];
        }
    }

    if (avLayers.length <= 1) {
        alert("トラックマットが有効なレイヤーを2つ以上選択してください.", "Mutual Track Mat");
        return 0;
    }

    app.beginUndoGroup("Mutual Track Mat");

    var loopCount = avLayers.length;
    while (loopCount > 0) {
        avLayers[0].setTrackMatte(avLayers[1], TrackMatteType.ALPHA);
        avLayers[avLayers.length] = avLayers.shift();
        loopCount--;
    }

    for (var i = 0; i < avLayers.length; i++) {
        avLayers[i].enabled = true;
    }

    app.endUndoGroup();

    return 0;
}).call(this);